
 /*****************************************************************************
**   Include files
******************************************************************************/
 #include "LPC2103.h"  
 #include "spi.h"
 
 
/**
 * Initializes the SPI0 interface.
 *
 * @param char number of bits per transfer
 */
void initSPI0(unsigned char bits)
{
	// configure pins
	PINSEL0 |= (1<<8)  |				// SCK0 
			   (1<<10) |				// MISO0
			   (1<<12); 				// MOSI0
	
	if (bits <= 8) S0SPCR = (1<<4) |	// clock polarity = active low
							(1<<5);	  	// master mode
	else if (bits < 16)
	{					   
		S0SPCR = (1<<2) |				// transmit more than 8 bits
				 (1<<4) |				// clock polarity = active low
				 (1<<5) |				// master mode
			     (bits<<8);				// set number of bits
	}
	else
	{					   
		S0SPCR = (1<<2) |				// transmit more than 8 bits
				 (1<<4) |				// clock polarity = active low
				 (1<<5);				// master mode
	}
	
	// spi clock = fcpu / 8
	S0SPCCR = 8;
}


/**
 * Initializes the SPI1 interface.
 *
 * @param char number of bits per transfer
 */
void initSPI1(unsigned char bits)
{
	// configure pins
	PINSEL0 |= (2<<28);					// SCK1
	PINSEL1 |= (1<<6) |					// MISO1 
			   (1<<8);					// MOSI1
	
	// check number of bits
	if (bits >= 4 && bits <= 16) bits--;// adjustment, see chapter 13.4.1 of datasheet
	else bits = 7;						// default: 8 bits
	
	SSPCR0  = (bits<<0) |				// data size select
			  (1<<6);
			  
	SSPCR1  = (1<<1);					// SSP enabled, SPI master mode
	
	SSPCPSR = 2;						// SSP clock prescale value CPSDVSR
}


/**
 *  Transmits and receives data via SPI0
 *
 *	@param int data character to write
 *	@return char character read
 */
int SPI0(unsigned int data)
{
	// write byte and start transmission
	S0SPDR = data;
	
	// wait until transmission is finished (SPIF set)
	while(!(S0SPSR & (1<<7))) {}
	
	// return received byte
	return S0SPDR;
}


/**
 *  Transmits and receives data via SPI1
 *
 *	@param int data character to write
 *	@return char character read
 */
int SPI1(unsigned int data)
{
	// write byte and start transmission
	SSPDR = data;
	
	// wait until transmission is finished (BSY cleared)
	while(SSPSR & (1<<4)) {}
	
	// return received byte
	return SSPDR;
}

